Index: test/cctest/test-log.cc |
diff --git a/test/cctest/test-log.cc b/test/cctest/test-log.cc |
index aca9492b0461b847f01f199cdfd2679bd99a0865..005be475ecab551e416cc20d6196a6fb5debbe77 100644 |
--- a/test/cctest/test-log.cc |
+++ b/test/cctest/test-log.cc |
@@ -166,9 +166,11 @@ static int CheckThatProfilerWorks(int log_pos) { |
"for (var i = 0; i < 1000; ++i) { " |
"(function(x) { return %d * x; })(i); }", |
log_pos); |
- // Run code for 200 msecs to get some ticks. |
- const int64_t started_us = i::OS::Ticks(); |
- while (i::OS::Ticks() - started_us < 200 * 1000) { |
+ // Run code for 200 msecs to get some ticks. Use uint to always have |
+ // non-negative delta. |
+ const uint64_t started_us = i::OS::Ticks(); |
+ uint64_t delta; |
+ while ((delta = i::OS::Ticks() - started_us) < 200 * 1000) { |
William Hesse
2009/05/29 12:19:49
The condition should really be
(ended_us = ticks()
William Hesse
2009/05/29 12:55:32
Actually, we don't really understand what is going
|
CompileAndRunScript(script_src.start()); |
} |